@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+import ipaddress
 import socket
 
 import pytest
@@ -8,15 +8,15 @@ _true_connect = socket.socket.connect
 
 
 class SocketBlockedError(RuntimeError):
-    def __init__(self, *args, **kwargs):
-        super(SocketBlockedError, self).__init__("A test tried to use socket.socket.")
+    def __init__(self, *_args, **_kwargs):
+        super().__init__("A test tried to use socket.socket.")
 
 
 class SocketConnectBlockedError(RuntimeError):
-    def __init__(self, allowed, host, *args, **kwargs):
+    def __init__(self, allowed, host, *_args, **_kwargs):
         if allowed:
             allowed = ",".join(allowed)
-        super(SocketConnectBlockedError, self).__init__(
+        super().__init__(
             "A test tried to use socket.socket.connect() "
             f'with host "{host}" (allowed: "{allowed}").'
         )
@@ -171,16 +171,54 @@ def host_from_connect_args(args):
         return host_from_address(address)
 
 
+def is_ipaddress(address: str) -> bool:
+    """
+    Determine if the address is a valid IPv4 or IPv6 address.
+    """
+    try:
+        ipaddress.ip_address(address)
+        return True
+    except ValueError:
+        return False
+
+
+def resolve_hostname(hostname):
+    try:
+        return socket.gethostbyname(hostname)
+    except socket.gaierror:
+        return None
+
+
+def normalize_allowed_hosts(allowed_hosts):
+    """Convert all items in `allowed_hosts` to an IP address."""
+    ip_hosts = []
+    for host in allowed_hosts:
+        host = host.strip()
+        if is_ipaddress(host):
+            ip_hosts.append(host)
+        else:
+            resolved = resolve_hostname(host)
+            if resolved:
+                ip_hosts.append(resolved)
+
+    return ip_hosts
+
+
 def socket_allow_hosts(allowed=None, allow_unix_socket=False):
     """disable socket.socket.connect() to disable the Internet. useful in testing."""
     if isinstance(allowed, str):
         allowed = allowed.split(",")
+
     if not isinstance(allowed, list):
         return
 
+    allowed_hosts = normalize_allowed_hosts(allowed)
+
     def guarded_connect(inst, *args):
         host = host_from_connect_args(args)
-        if host in allowed or (_is_unix_socket(inst.family) and allow_unix_socket):
+        if host in allowed_hosts or (
+            _is_unix_socket(inst.family) and allow_unix_socket
+        ):
             return _true_connect(inst, *args)
 
         raise SocketConnectBlockedError(allowed, host)
